@@ -1,7 +1,7 @@
 package Markdown::To::POD;
 
-our $DATE = '2016-09-26'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.06'; # VERSION
 # ABSTRACT: Convert Markdown syntax to POD
 
 use 5.010001;
@@ -1375,7 +1375,7 @@ sub _DoAutoLinks {
     # pm: and prog:
     $text =~ s{
         <
-        (?:pm|prog):(?://?)?
+        (?:pm|pod|prog):(?://?)?
         (
             [\w-]+(?:::[\w-]+)*
         )
@@ -1540,7 +1540,7 @@ Markdown::To::POD - Convert Markdown syntax to POD
 
 =head1 VERSION
 
-This document describes version 0.05 of Markdown::To::POD (from Perl distribution Markdown-To-POD), released on 2016-09-26.
+This document describes version 0.06 of Markdown::To::POD (from Perl distribution Markdown-To-POD), released on 2016-09-27.
 
 =head1 SYNOPSIS
 
@@ -1783,7 +1783,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Markdown-T
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Markdown-To-POD>.
+Source repository is at L<https://github.com/perlancar/perl-Markdown-To-POD>.
 
 =head1 BUGS
 
